@@ -1,7 +1,7 @@
 """
 Description for boto3 service.
 """
-from typing import Dict, Literal
+from typing import Literal
 
 from mypy_boto3_builder.constants import MODULE_NAME, PYPI_NAME
 from mypy_boto3_builder.utils.strings import get_anchor_link, is_reserved
@@ -194,7 +194,7 @@ class ServiceNameCatalog:
     logs = ServiceName("logs", "CloudWatchLogs")
     lambda_ = ServiceName("lambda", "Lambda")
 
-    ITEMS: Dict[str, ServiceName] = {
+    ITEMS: dict[str, ServiceName] = {
         ec2.name: ec2,
         iam.name: iam,
         s3.name: s3,
