@@ -1,8 +1,8 @@
 """
 Jinja2 renderer and black formatter.
 """
+from collections.abc import Iterable
 from pathlib import Path
-from typing import Iterable, Optional
 
 import black
 import mdformat
@@ -88,8 +88,8 @@ def sort_imports(
 
 def render_jinja2_template(
     template_path: Path,
-    package: Optional[Package] = None,
-    service_name: Optional[ServiceName] = None,
+    package: Package | None = None,
+    service_name: ServiceName | None = None,
 ) -> str:
     """
     Render Jinja2 template to a string.
@@ -117,7 +117,7 @@ def insert_md_toc(text: str) -> str:
     toc = TableOfContents.parse(text)
     toc_lines = toc.render().splitlines()
     lines = text.splitlines()
-    result = []
+    result: list[str] = []
     inserted = False
     for line in lines:
         if not inserted and line.startswith("## "):
